@@ -5,14 +5,14 @@ use strict;
 use warnings;
 
 our @ISA = qw/Exporter/;
-our @EXPORT_OK = qw/truncate_text wrap_text string_to_id missing_array_items not_blank split_words line_split mask_text/;
+our @EXPORT_OK = qw/truncate_text wrap_text string_to_id missing_array_items not_blank split_words line_split mask_text split_camel_case/;
 
 use Array::Utils qw/intersect array_minus/;
 use Scalar::Util qw/looks_like_number/;
 
 # ABSTRACT: Simple text utilities
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 
 
@@ -144,6 +144,14 @@ sub mask_text
 }
 
 
+sub split_camel_case
+{
+    my $text = shift;
+    # a lot of the credit for this goes to the Perl Monks.
+    my @parts = $text =~ /[A-Z0-9](?:[A-Z0-9]+|[^A-Z0-9]*)(?=$|[A-Z0-9])/g;
+    return \@parts;
+}
+
 1; # End of OpusVL::Text::Util
 
 __END__
@@ -158,7 +166,7 @@ OpusVL::Text::Util - Simple text utilities
 
 =head1 VERSION
 
-version 0.09
+version 0.10
 
 =head1 SYNOPSIS
 
@@ -243,6 +251,14 @@ Specify a fill character, a regex (as a string), and the text to mask out.
 This does not guard against rogue regexes.  Capture the parts you expect to
 be retained.
 
+=head2 split_camel_case
+
+Split a camel case word into an arrayref.  This assumes you're giving it a word,
+behaviour when passed something like a sentence is undefined.
+
+    split_camel_case('TemplateNotMatchedException')
+    # ['Template', 'Not', 'Matched', 'Exception']
+
 =head1 AUTHOR
 
 Colin Newell <colin@opusvl.com>
